@@ -469,7 +469,7 @@ void QtProfileBar::phoneLineCreatedEventHandler(UserProfile & sender, IPhoneLine
 void QtProfileBar::phoneLineCreatedEventSlot() {
 	if(_cUserProfile)
 	{
-		_nicknameLabel->setText("  " + QString::fromLocal8Bit(_cUserProfile->getUserProfile().getSipAccount()->getDisplayName().c_str()));
+		_nicknameLabel->setText("  " + QString::fromUtf8(_cUserProfile->getUserProfile().getSipAccount()->getDisplayName().c_str()));
 	}
 }
 
